import React, { useState, useEffect } from "react";
import { toast } from "react-toastify";

const Coach = () => {
  const [name, setName] = useState("");
  const [title, setTitle] = useState("");
  const [coaches, setCoaches] = useState([]);
  const [message, setMessage] = useState("");
  const [editingId, setEditingId] = useState(null);

  const API_BASE_URL = import.meta.env.VITE_API_BASE_URL;

  // Fetch coaches
  const fetchCoaches = async () => {
    try {
      const response = await fetch(API_BASE_URL + "/coach");
      const data = await response.json();
      if (response.ok) {
        setCoaches(data.data);
      } else {
        setMessage(`Error: ${data.message}`);
      }
    } catch (error) {
      setMessage(`Error: ${error.message}`);
    }
  };

  useEffect(() => {
    fetchCoaches();
  }, []);

  // Add new coach
  const addCoach = async () => {
    if (!name || !title) {
      setMessage("Both name and title are required.");
      return;
    }

    try {
      const response = await fetch(`${API_BASE_URL}/coach`, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({ name, title }),
      });

      const data = await response.json();

      if (response.ok) {
        setCoaches((prev) => [...prev, data.data]);
        toast.success("Coach added successfully!");
        setName("");
        setTitle("");
      } else {
        setMessage(`Error: ${data.message}`);
      }
    } catch (error) {
      setMessage(`Error: ${error.message}`);
    }
  };

  // Update coach
  const updateCoach = async () => {
    if (!name || !title) {
      setMessage("Both name and title are required.");
      return;
    }
    try {
      const response = await fetch(`${API_BASE_URL}/coach/${editingId}`, {
        method: "PUT",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({ name, title }),
      });

      const data = await response.json();

      if (response.ok) {
        setCoaches((prev) =>
          prev.map((coach) =>
            coach.id === editingId ? { ...coach, name, title } : coach
          )
        );
        toast.success("Coach updated successfully!");
        setName("");
        setTitle("");
        setEditingId(null);
      } else {
        setMessage(`Error: ${data.message}`);
      }
    } catch (error) {
      setMessage(`Error: ${error.message}`);
    }
  };

  // Edit coach
  const startEditing = (coach) => {
    setEditingId(coach.id);
    setName(coach.name);
    setTitle(coach.title);
  };

  // Delete coach
  const removeCoach = async (id) => {
    try {
      const response = await fetch(`${API_BASE_URL}/coach/${id}`, {
        method: "DELETE",
      });

      if (response.ok) {
        setCoaches((prev) => prev.filter((coach) => coach.id !== id));
        toast.success("Coach removed successfully!");
      } else {
        const data = await response.json();
        setMessage(`Error: ${data.message}`);
      }
    } catch (error) {
      setMessage(`Error: ${error.message}`);
    }
  };

  return (
    <div>
      <h2 className="text-2xl font-semibold mb-4">Manage Coaches</h2>

      {/* Success/Error Message */}
      {message && <p className="mb-4 text-red-500">{message}</p>}

      <div className="mb-6 grid grid-cols-1 gap-4 md:grid-cols-2">
        <input
          type="text"
          placeholder="Coach Name"
          value={name}
          onChange={(e) => setName(e.target.value)}
          className="px-4 py-2 border rounded-lg bg-gray-800 text-white focus:ring focus:ring-gray-500"
        />
        <input
          type="text"
          placeholder="Coach Title"
          value={title}
          onChange={(e) => setTitle(e.target.value)}
          className="px-4 py-2 border rounded-lg bg-gray-800 text-white focus:ring focus:ring-gray-500"
        />
        <button
          onClick={editingId ? updateCoach : addCoach}
          className="bg-white text-black px-4 py-2 rounded-lg w-36 hover:bg-gray-300 cursor-pointer"
        >
          {editingId ? "Update Coach" : "Add Coach"}
        </button>
      </div>

      {/* Coach List */}
      <ul className="space-y-4 mt-16">
        <h2 className="text-2xl font-semibold mb-4">Coahes</h2>
        {coaches.map((coach) => (
          <li
            key={coach.id}
            className="flex items-center justify-between bg-gray-800 p-4 rounded-lg shadow-md"
          >
            <div>
              <h3 className="text-lg font-medium text-white">{coach.name}</h3>
              <p className="text-gray-400">{coach.title}</p>
            </div>
            <div className="flex items-center space-x-2">
              <button
                onClick={() => startEditing(coach)}
                className="bg-blue-500 text-white px-4 py-2 rounded-lg hover:bg-blue-600 cursor-pointer"
              >
                Edit
              </button>
              <button
                onClick={() => removeCoach(coach.id)}
                className="bg-red-500 text-white px-4 py-2 rounded-lg hover:bg-red-600 cursor-pointer"
              >
                Remove
              </button>
            </div>
          </li>
        ))}
      </ul>
    </div>
  );
};

export default Coach;
