import React, { useState, useEffect } from "react";
import axios from "axios";
import { toast } from "react-toastify";

const Events = () => {
  const [events, setEvents] = useState([]);
  const [form, setForm] = useState({ title: "", description: "", date: "" });
  const [errorMessage, setErrorMessage] = useState("");
  const [editId, setEditId] = useState(null);

  const API_BASE_URL = import.meta.env.VITE_API_BASE_URL

  // Fetch events
  const fetchEvents = async () => {
    try {
      const response = await axios.get(`${API_BASE_URL}/event`);
      setEvents(response.data.data);
    } catch (error) {
      console.error("Error fetching events:", error);
    }
  };

  // Validate fields
  const validateForm = () => {
    if (!form.title || !form.description || !form.date) {
      setErrorMessage("All fields are required.");
      return false;
    }
    setErrorMessage("");
    return true;
  };

  // Add a new event
  const addEvent = async () => {
    if (!validateForm()) return;
    try {
      const isoDate = new Date(form.date).toISOString();
      const response = await axios.post(`${API_BASE_URL}/event`, {
        ...form,
        date: isoDate,
      });
      setEvents((prev) => [...prev, response.data.data]);
      toast.success("Event added successfully!");
      setForm({ title: "", description: "", date: "" });
    } catch (error) {
      console.error("Error adding event:", error);
    }
  };

  // Delete an event
  const deleteEvent = async (id) => {
    try {
      await axios.delete(`${API_BASE_URL}/event/${id}`);
      setEvents((prev) => prev.filter((event) => event.id !== id));
      toast.success("Event deleted successfully!");
    } catch (error) {
      console.error("Error deleting event:", error);
    }
  };

  // Update an event
  const updateEvent = async () => {
    if (!validateForm()) return;
    try {
      const isoDate = new Date(form.date).toISOString();
      const response = await axios.put(
        `${API_BASE_URL}/event/${editId}`,
        {
          ...form,
          date: isoDate,
        }
      );
      setEvents((prev) =>
        prev.map((event) => (event.id === editId ? response.data.data : event))
      );
      toast.success("Event updated successfully!");
      setForm({ title: "", description: "", date: "" });
      setEditId(null);
    } catch (error) {
      console.error("Error updating event:", error);
    }
  };

  useEffect(() => {
    fetchEvents();
  }, []);

  // Handle form changes
  const handleChange = (e) => {
    setForm({ ...form, [e.target.name]: e.target.value });
  };

  // Handle edit
  const handleEdit = (event) => {
    setEditId(event.id);
    setForm({
      title: event.title,
      description: event.description,
      date: new Date(event.date).toISOString().split("T")[0],
    });
  };

  return (
    <div>
      <h2 className="text-2xl font-semibold mb-4">Events Calendar</h2>

      {/* Error Message */}
      {errorMessage && <div className="mb-4 text-red-500">{errorMessage}</div>}

      <div className="mb-6 grid grid-cols-1 gap-4 md:grid-cols-2">
        <input
          type="text"
          name="title"
          placeholder="Event Title"
          value={form.title}
          onChange={handleChange}
          className="px-4 py-2 border rounded-lg bg-gray-800 text-white focus:ring focus:ring-gray-500"
        />
        <input
          type="date"
          name="date"
          value={form.date}
          onChange={handleChange}
          className="px-4 py-2 border rounded-lg bg-gray-800 text-white focus:ring focus:ring-gray-500"
        />
        <textarea
          name="description"
          placeholder="Description"
          value={form.description}
          onChange={handleChange}
          className="col-span-2 px-4 py-2 border rounded-lg bg-gray-800 text-white focus:ring focus:ring-gray-500"
          rows="3"
        />
        {editId ? (
          <button
            onClick={updateEvent}
            className="bg-white text-black px-4 py-2 w-36 rounded-lg hover:bg-gray-300 cursor-pointer"
          >
            Update Event
          </button>
        ) : (
          <button
            onClick={addEvent}
            className="bg-white text-black px-4 py-2 w-36 rounded-lg hover:bg-gray-300 cursor-pointer"
          >
            Add Event
          </button>
        )}
      </div>

      {/* Event List */}
      <ul className="space-y-4 mt-16">
        <h2 className="text-2xl font-semibold mb-4">Events</h2>
        {events.map((event) => (
          <li
            key={event.id}
            className="flex items-center justify-between bg-gray-800 p-4 rounded-lg shadow-md"
          >
            <div>
              <h3 className="text-lg font-medium text-white">{event.title}</h3>
              <p className="text-gray-400 text-sm">
                {new Date(event.date).toLocaleDateString()}
              </p>
              <p className="text-gray-300">{event.description}</p>
            </div>
            <div className="flex gap-2">
              <button
                onClick={() => handleEdit(event)}
                className="bg-blue-500 text-white px-4 py-2 rounded-lg hover:bg-blue-600 cursor-pointer"
              >
                Edit
              </button>
              <button
                onClick={() => deleteEvent(event.id)}
                className="bg-red-500 text-white px-4 py-2 rounded-lg hover:bg-red-600 cursor-pointer"
              >
                Remove
              </button>
            </div>
          </li>
        ))}
      </ul>
    </div>
  );
};

export default Events;
